import Phaser from 'phaser';

class Example extends Phaser.Scene
{
  constructor () {
    super();
  }

  preload () {
    this.load.image('tiles', '/assets/tilesets/default.png');
  }

  create () {
    const mapData = new Phaser.Tilemaps.MapData({
      orientation: Phaser.Tilemaps.Orientation.ISOMETRIC,
      format: Phaser.Tilemaps.Formats.ARRAY_2D,
      width: 10,
      height: 10,
      tileWidth: 64,
      tileHeight: 32,
    });

    const map = new Phaser.Tilemaps.Tilemap(this, mapData);
    const tileset = map.addTilesetImage('default', 'tiles');
    const layer = map.createBlankLayer('layer', tileset);

    const data = [
      [ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ],
      [ 0, 1, 1, 1, 1, 1, 1, 1, 1, 0 ],
      [ 0, 1, 1, 1, 1, 1, 1, 1, 1, 0 ],
      [ 0, 1, 1, 1, 1, 1, 1, 1, 1, 0 ],
      [ 0, 1, 1, 1, 1, 1, 1, 1, 1, 0 ],
      [ 0, 1, 1, 1, 1, 1, 1, 1, 1, 0 ],
      [ 0, 1, 1, 1, 1, 1, 1, 1, 1, 0 ],
      [ 0, 1, 1, 1, 1, 1, 1, 1, 1, 0 ],
      [ 0, 1, 1, 1, 1, 1, 1, 1, 1, 0 ],
      [ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ],
    ];

    let y = 0;

    data.forEach(row => {
      row.forEach((tile, x) => {
        layer.putTileAt(tile, x, y);
      });
      y++;
    });

    // middle of the screen by default
    const centerX = map.widthInPixels / 1.5;
    const centerY = map.heightInPixels / 2;
    layer.setPosition(centerX, centerY);

    let cam = this.cameras.main;
    this.input.on("pointermove", function (p) {
      if (!p.isDown) return;
      cam.scrollX -= (p.x - p.prevPosition.x) / cam.zoom;
      cam.scrollY -= (p.y - p.prevPosition.y) / cam.zoom;
    });
  }
}

export default Example;